@@ -81,6 +81,7 @@ Enigmail.msg = {
         if (element) {
           try {
             var oldValue = element.getAttribute(attrName);
+            EnigmailCommon.DEBUG_LOG("enigmailMessengerOverlay.js: overrideAttribute "+attrName+": oldValue="+oldValue+"\n");
             var newValue = prefix+elementId+suffix;
 
             element.setAttribute(attrName, newValue);
@@ -477,6 +478,7 @@ Enigmail.msg = {
     };
 
     try {
+      if (gFolderDisplay.selectedMessageIsNews) throw "dummy"; // workaround for broken NNTP support in Gloda
       MsgHdrToMimeMessage(gFolderDisplay.selectedMessage , cbObj, Enigmail.msg.msgDecryptMimeCb, true);
     }
     catch (ex) {
@@ -488,21 +490,19 @@ Enigmail.msg = {
 
   msgDecryptMimeCb: function (msg, mimeMsg)
   {
-    var f = function(argList)
-    {
-      var enigmailSvc=Enigmail.getEnigmailSvc();
-      if (!enigmailSvc) return;
-
-      var event = argList[0];
-      var isAuto = argList[1];
-      var mimeMsg = argList[2];
-      Enigmail.msg.messageDecryptCb(event, isAuto, mimeMsg);
-    };
-
     // MsgHdrToMimeMessage is not on the main thread which may lead to problems with
     // accessing DOM and debugging
 
-    EnigmailCommon.dispatchEvent(f, 0, [this.event, this.isAuto, mimeMsg])
+    EnigmailCommon.dispatchEvent(
+      function(argList) {
+        var enigmailSvc=Enigmail.getEnigmailSvc();
+        if (!enigmailSvc) return;
+
+        var event = argList[0];
+        var isAuto = argList[1];
+        var mimeMsg = argList[2];
+        Enigmail.msg.messageDecryptCb(event, isAuto, mimeMsg);
+      }, 0, [this.event, this.isAuto, mimeMsg])
   },
 
 
@@ -527,15 +527,18 @@ Enigmail.msg = {
   {
     EnigmailCommon.DEBUG_LOG("enumerateMimeParts: "+mimePart.partName+" - "+mimePart.headers["content-type"]+"\n");
 
-    // does not work properly because MsgHdrToMimeMessage() cannot [yet] handle inner parts of encrypted messages
-
-    var ct = mimePart.headers["content-type"][0];
-    if (typeof(ct) == "string") {
-      if (ct.search(/multipart\/signed.*application\/pgp-signature/i) >= 0) {
-        resultObj.signed=mimePart.partName;
+    try {
+      var ct = mimePart.headers["content-type"][0];
+      if (typeof(ct) == "string") {
+        if (ct.search(/multipart\/signed.*application\/pgp-signature/i) >= 0) {
+          resultObj.signed=mimePart.partName;
+        }
+        else if (ct.search(/application\/pgp-encrypted/i) >= 0)
+          resultObj.encrypted=mimePart.partName;
       }
-      else if (ct.search(/application\/pgp-encrypted/i) >= 0)
-        resultObj.encrypted=mimePart.partName;
+    }
+    catch (ex) {
+      // catch exception if no headers or no content-type defined.
     }
 
     var i;
@@ -556,7 +559,12 @@ Enigmail.msg = {
 
       if (mimeMsg == null) {
         EnigmailCommon.DEBUG_LOG("enigmailMessengerOverlay.js: messageDecryptCb: mimeMsg is null\n");
-        contentType=currentHeaderData['content-type'].headerValue;
+        try {
+          contentType=currentHeaderData['content-type'].headerValue;
+        }
+        catch (ex) {
+          contentType = "text/plain";
+        }
         mimeMsg = {
           headers: {'content-type': contentType },
           contentType: contentType,
@@ -754,33 +762,25 @@ Enigmail.msg = {
     var foundIndex = -1;
 
 
-    if (EnigmailCommon.getPref("enableExperiments")) {
-      if (bodyElement.firstChild) {
-        let node = bodyElement.firstChild
-        while (node) {
-          if (node.nodeName == "DIV") {
-            foundIndex = node.textContent.indexOf(findStr);
+    if (bodyElement.firstChild) {
+      let node = bodyElement.firstChild
+      while (node) {
+        if (node.nodeName == "DIV") {
+          foundIndex = node.textContent.indexOf(findStr);
 
-            if (foundIndex >= 0) {
-              if (node.textContent.indexOf(findStr+" LICENSE AUTHORIZATION") == foundIndex)
-                foundIndex = -1;
-            }
-            if (foundIndex >= 0) {
-              bodyElement = node;
-              break;
-            }
+          if (foundIndex >= 0) {
+            if (node.textContent.indexOf(findStr+" LICENSE AUTHORIZATION") == foundIndex)
+              foundIndex = -1;
+          }
+          if (foundIndex >= 0) {
+            bodyElement = node;
+            break;
           }
-          node = node.nextSibling;
         }
+        node = node.nextSibling;
       }
     }
-    else if (findStr) {
-      foundIndex = bodyElement.textContent.indexOf(findStr);
-      if (foundIndex >= 0) {
-        if (bodyElement.textContent.indexOf(findStr+" LICENSE AUTHORIZATION") == foundIndex)
-          foundIndex = -1;
-      }
-    }
+
     if (foundIndex >= 0) {
       msgText = bodyElement.textContent;
     }
@@ -1076,6 +1076,7 @@ Enigmail.msg = {
       var node = bodyElement.firstChild;
       var foundIndex = -1;
       var findStr = "-----BEGIN PGP";
+
       while (node) {
         if (node.nodeName == "DIV") {
           foundIndex = node.textContent.indexOf(findStr);
@@ -1085,13 +1086,32 @@ Enigmail.msg = {
               foundIndex = -1;
           }
           if (foundIndex >= 0) {
-            // EnigmailCommon.DEBUG_LOG("enigmailMessengerOverlay.js: innerHTML='"+node.innerHTML+"'\n");
             node.innerHTML = EnigmailFuncs.formatPlaintextMsg(EnigmailCommon.convertToUnicode(messageContent, charset));
             return;
           }
         }
         node = node.nextSibling;
       }
+
+      // if no <DIV> node is found, try with <PRE> (bug 24762)
+      node = bodyElement.firstChild;
+      foundIndex = -1;
+      while (node) {
+        if (node.nodeName == "PRE") {
+          foundIndex = node.textContent.indexOf(findStr);
+
+          if (foundIndex >= 0) {
+            if (node.textContent.indexOf(findStr+" LICENSE AUTHORIZATION") == foundIndex)
+              foundIndex = -1;
+          }
+          if (foundIndex >= 0) {
+            node.innerHTML = EnigmailFuncs.formatPlaintextMsg(EnigmailCommon.convertToUnicode(messageContent, charset));
+            return;
+          }
+        }
+        node = node.nextSibling;
+      }
+
     }
 
     EnigmailCommon.ERROR_LOG("enigmailMessengerOverlay.js: no node found to replace message display\n");
@@ -1099,11 +1119,6 @@ Enigmail.msg = {
     return;
   },
 
-  // this is an attempt to re-build some of the functionality of mimetpla.cpp in JS
-  displayMessage: function (messageContent, node) {
-
-
-  },
 
   // check if an attachment could be signed
   checkSignedAttachment: function (attachmentObj, index)
@@ -1655,8 +1670,7 @@ Enigmail.msg = {
         var uri = Components.classes[EnigmailCommon.SIMPLEURI_CONTRACTID].createInstance(Components.interfaces.nsIURI);
         uri.spec = "enigmail:dummy";
 
-        var ipcService = Components.classes[EnigmailCommon.IPCSERVICE_CONTRACTID].getService(Components.interfaces.nsIIPCService);
-        var channel = ipcService.newStringChannel(uri, "", "", txt);
+        var channel = EnigmailCommon.newStringChannel(uri, "", "", txt);
         var verifier = Components.classes[EnigmailCommon.ENIGMIMEVERIFY_CONTRACTID].createInstance(Components.interfaces.nsIEnigMimeVerify);
 
         verifier.initWithChannel(callbackArg.window, channel, callbackArg.msgWindow, callbackArg.msgUriSpec,
@@ -1672,10 +1686,12 @@ Enigmail.msg = {
   },
 
 
-  revealAttachments: function ()
+  revealAttachments: function (index)
   {
-    for (let i=0; i < currentAttachments.length; i++) {
-      this.handleAttachment("revealName", currentAttachments[i]);
+    if (!index) index = 0;
+
+    if (index < currentAttachments.length) {
+      this.handleAttachment("revealName/"+index.toString(), currentAttachments[index]);
     }
   },
 
@@ -1685,9 +1701,15 @@ Enigmail.msg = {
   {
     EnigmailCommon.DEBUG_LOG("enigmailMessengerOverlay.js: handleAttachmentSel: actionType="+actionType+"\n");
 
-    var contextMenu = document.getElementById('attachmentListContext');
+    // Thunderbird
+    var contextMenu = document.getElementById('attachmentItemContext');
     var selectedAttachments = contextMenu.attachments;
 
+    if (! contextMenu) {
+      // SeaMonkey
+      contextMenu = document.getElementById('attachmentListContext');
+      selectedAttachments = attachmentList.selectedItems;
+    }
     var anAttachment = selectedAttachments[0];
 
     switch (actionType) {
@@ -1844,14 +1866,20 @@ Enigmail.msg = {
     channel.asyncOpen(ipcBuffer, msgUri);
   },
 
-  setAttachmentName: function (attachment, newLabel)
+  setAttachmentName: function (attachment, newLabel, index)
   {
+    EnigmailCommon.DEBUG_LOG("enigmailMessengerOverlay.js: setAttachmentName ("+newLabel+"):\n");
+
     var attList=document.getElementById("attachmentList");
     if (attList) {
       var attNode = attList.firstChild;
       while (attNode) {
+        // TB <= 9
         if (attNode.getAttribute("attachmentUrl") == attachment.url)
           attNode.setAttribute("label", newLabel);
+        // TB >= 10
+        if (attNode.getAttribute("name") == attachment.name)
+          attNode.setAttribute("name", newLabel);
         attNode=attNode.nextSibling;
       }
     }
@@ -1861,6 +1889,10 @@ Enigmail.msg = {
     }
     else
       attachment.displayName = newLabel;
+
+    if (index && index.length > 0) {
+      this.revealAttachments(parseInt(index)+1);
+    }
   },
 
   decryptAttachmentCallback: function (cbArray)
@@ -1895,9 +1927,9 @@ Enigmail.msg = {
                                   rawFileName, null);
       if (! outFile) return;
     }
-    else if (callbackArg.actionType == "revealName") {
+    else if (callbackArg.actionType.substr(0,10) == "revealName") {
       if (origFilename && origFilename.length > 0) {
-        Enigmail.msg.setAttachmentName(callbackArg.attachment, origFilename+".pgp");
+        Enigmail.msg.setAttachmentName(callbackArg.attachment, origFilename+".pgp", callbackArg.actionType.substr(11,10));
       }
       Enigmail.msg.setAttachmentReveal(null);
       return;
